[Mesh]
  type = FileMesh
  file = slope_ss_out.e
[]

[GlobalParams]
  richardsVarNames_UO = PPNames
  density_UO = DensityConstBulk
  relperm_UO = RelPermPower
  SUPG_UO = SUPGstandard
  sat_UO = Saturation
  seff_UO = SeffVG
  viscosity = 3.171E-11  # 1E-3 Pa.s
  gravity = '0 0 -10'
  linear_shape_fcns = true
[]

[UserObjects]
  [./PPNames]
    type = RichardsVarNames
    richards_vars = pp
  [../]
  [./DensityConstBulk]
    type = RichardsDensityConstBulk
    dens0 = 1000
    bulk_mod = 2E9
  [../]
  [./SeffVG]
    type = RichardsSeff1VG
    m = 0.6
    al = 1E-4
  [../]
  [./RelPermPower]
    type = RichardsRelPermPower
    simm = 0.0
    n = 2
  [../]
  [./Saturation]
    type = RichardsSat
    s_res = 0.1
    sum_s_res = 0.1
  [../]
  [./SUPGstandard]
    type = RichardsSUPGnone  # note, no upwinding as it's probably unnecessary for this simulation
  [../]
  [./baseflow_uo]
    type = RichardsSumQuantity
  [../]
[]


[Variables]
  [./pp]
    initial_from_file_timestep = 55
    initial_from_file_var = pp
  [../]
[]


[Kernels]
  [./richardst]
    type = RichardsMassChange
    variable = pp
  [../]
  [./richardsf]
    type = RichardsFullyUpwindFlux
    variable = pp
  [../]
[]

[BCs]
  [./top_land_rain]
    type = RichardsPiecewiseLinearSink
    boundary = top
    pressures = '-1E6 1E6'
    bare_fluxes = '-50 -50' # constant rainfall of 50mm/year (=50kg/m^2/year)
    use_mobility = false
    use_relperm = false
    variable = pp
  [../]
  [./top_land_ET]
    type = BAHalfCubicSink
    boundary = top
    centre = 2E4 # 2metres above land top
    max = 1500E-1 # 1500mm/year potential ET
    cutoff = -7E4 # 5metres below land top
    variable = pp
  [../]
  [./bottom_extraction]
    type = RichardsPiecewiseLinearSink
    boundary = bottom
    pressures = '-1E6 1E6'
    bare_fluxes = '1 1'
    use_mobility = false
    use_relperm = false
    multiplying_fcn = mine_water_make
    variable = pp
  [../]
  [./bottom_not_mine_injection]
    type = RichardsPiecewiseLinearSink
    boundary = 3
    pressures = '-1E6 1E6'
    bare_fluxes = '-1 -1'
    use_mobility = false
    use_relperm = false
    multiplying_fcn = mine_water_make
    variable = pp
  [../]
[]

[DiracKernels]
  [./river]
    type = RichardsPolyLineSink
    fluxes = '-3E7 3E7'
    pressures = '-1E6 1E6'
    variable = pp
    point_file = 'slope_river.txt'
    SumQuantityUO = baseflow_uo
  [../]
[]

[Postprocessors]
  [./et_kg_this_timestep]
    type = BAHalfCubicSinkFlux
    boundary = top
    centre = 2E4 # 2metres above land top
    max = 1500E-1 # 1500mm/year potential ET
    cutoff = -7E4 # 5metres below land top
    variable = pp
    outputs = 'none'
  [../]
  [./et_rate]
    type = FunctionValuePostprocessor
    function = etr
  [../]
  [./rain_kg_per_year]
    type = FunctionSideIntegral
    function = 5
    boundary = top
  [../]
  [./baseflow]
    type = RichardsPlotQuantity
    uo = baseflow_uo
    outputs = 'none'
  [../]
  [./baseflow_rate]
    type = FunctionValuePostprocessor
    function = bfr
  [../]
  [./old_timestep]
    type = TimestepSize
    outputs = 'none'
  [../]
  [./num_nli]
    type = NumNonlinearIterations
    outputs = 'none'
  [../]
  [./new_timestep]
    type = FunctionValuePostprocessor
    function = timestep_function
    outputs = 'none'
  [../]
  [./actual_timestep]
    type = TimestepSize
    outputs = 'none'
    execute_on = linear
  [../]
[]

[AuxVariables]
  [./pchange]
  [../]
  [./zeroaux]
    initial_condition = 0
  [../]
[]

[AuxKernels]
  [./pchange]
    type = FunctionAux
    variable = pchange
    function = if(t<0.05,0,2*min((t-0.05)/50,1))
  [../]
[]

[Functions]
  [./bfr]
    type = ParsedFunction
    value = 'a/b'
    vars = 'a b'
    vals = 'baseflow actual_timestep'
  [../]
  [./etr]
    type = ParsedFunction
    value = 'a/b'
    vars = 'a b'
    vals = 'et_kg_this_timestep actual_timestep'
  [../]
  [./timestep_function]
    type = ParsedFunction
    value = if(t<0.05,0.01,min(dt*max(1-0.1*(n-6),0.5),10000))
    vars = 'n dt'
    vals = 'num_nli old_timestep'
  [../]
  [./mine_water_make]
    type = PiecewiseLinear
    x = '0.05 50 51'
    y = '0 200 0'
  [../]
[]

[Materials]
  [./rock]
    type = RichardsMaterial
    block = 1
    mat_porosity = 0.1
    mat_permeability = '1E-15 0 0  0 1E-15 0  0 0 1E-15'
  [../]
  [./rock_above_mine]
    type = RichardsMaterial
    block = 2
    mat_porosity = 0.1
    mat_permeability = '1E-15 0 0  0 1E-15 0  0 0 1E-15'
    perm_change = 'pchange zeroaux zeroaux  zeroaux pchange zeroaux  zeroaux zeroaux pchange'
  [../]
[]

[Preconditioning]
  [./andy]
    type = SMP
    full = true
    petsc_options = '-snes_converged_reason -snes_linesearch_monitor'
    petsc_options_iname = '-ksp_type -pc_type -snes_atol -snes_rtol -snes_max_it -ksp_max_it -sub_pc_type -sub_pc_factor_shift_type -ksp_rtol'
    petsc_options_value = 'gmres asm 1E-5 1E-10 10 500 lu NONZERO 1E-6'
  [../]
[]


[Executioner]
  type = Transient
  start_time = 0
  end_time = 1E5
  solve_type = Newton
  [./TimeStepper]
    type = PostprocessorDT
    dt = 0.01
    postprocessor = new_timestep
  [../]
[]


[Outputs]
  file_base = slope_enhancement_gradually_increasing_out
  exodus = true
  csv = true
[]
